<?php
/*
Plugin Name: Stop Comments
Description: Provides an option to enable or disable comments across the site, removes comment forms, and prevents comment-related notifications.
Version: 1.2
Author: Dr. Rob White
*/

// Add menu item for Stop Comments settings page
function stop_comments_add_admin_menu() {
    add_menu_page(
        'Stop Comments Settings',
        'Stop Comments',
        'manage_options',
        'stop-comments',
        'stop_comments_settings_page',
        'dashicons-admin-comments',
        100
    );
}
add_action('admin_menu', 'stop_comments_add_admin_menu');

// Display the settings page
function stop_comments_settings_page() {
    // Check if the user has submitted the form
    if (isset($_POST['stop_comments_nonce']) && wp_verify_nonce($_POST['stop_comments_nonce'], 'stop_comments_save_settings')) {
        // Sanitize and save the option
        $status = isset($_POST['stop_comments_status']) ? sanitize_text_field($_POST['stop_comments_status']) : 'disabled';
        update_option('stop_comments_status', $status);

        // Update admin settings based on the status
        if ($status === 'disabled') {
            stop_comments_update_admin_settings();
        } else {
            update_option('default_comment_status', 'open');
            update_option('default_ping_status', 'open');
        }

        echo '<div class="updated"><p>' . esc_html('Settings saved.') . '</p></div>';
    }

    // Get the current status
    $current_status = get_option('stop_comments_status', 'disabled');
    $plugin_version = '1.2'; // Current version of the plugin
    ?>
    <div class="wrap">
        <h1><?php echo esc_html('Stop Comments Settings'); ?> - <?php echo esc_html($plugin_version); ?></h1>
        <p><?php echo esc_html('The plugin is by Delphi Enterprises, LLC.'); ?></p>
        <form method="post" action="">
            <?php wp_nonce_field('stop_comments_save_settings', 'stop_comments_nonce'); ?>
            <table class="form-table">
                <tr valign="top">
                    <th scope="row"><?php echo esc_html('Comments Status'); ?></th>
                    <td>
                        <select name="stop_comments_status" id="stop_comments_status">
                            <option value="enabled" <?php selected($current_status, 'enabled'); ?>><?php echo esc_html('Enabled'); ?></option>
                            <option value="disabled" <?php selected($current_status, 'disabled'); ?>><?php echo esc_html('Disabled'); ?></option>
                        </select>
                    </td>
                </tr>
            </table>
            <?php submit_button(); ?>
        </form>
    </div>
    <?php
}

// Disable comments on the front-end if disabled
function stop_comments_disable_comments_status($open, $post_id) {
    $status = get_option('stop_comments_status', 'disabled');
    return $status === 'disabled' ? false : $open;
}
add_filter('comments_open', 'stop_comments_disable_comments_status', 20, 2);
add_filter('pings_open', 'stop_comments_disable_comments_status', 20, 2);

// Hide existing comments if disabled
function stop_comments_hide_existing_comments($comments) {
    $status = get_option('stop_comments_status', 'disabled');
    return $status === 'disabled' ? array() : $comments;
}
add_filter('comments_array', 'stop_comments_hide_existing_comments', 10, 2);

// Remove comment form from the front-end if disabled
function stop_comments_remove_comment_form() {
    $status = get_option('stop_comments_status', 'disabled');
    if ($status === 'disabled') {
        remove_action('comment_form', 'comment_form');
    }
}
add_action('wp_head', 'stop_comments_remove_comment_form');

// Disable comment-related notifications if disabled
function stop_comments_disable_comment_notifications($open, $post_id) {
    $status = get_option('stop_comments_status', 'disabled');
    return $status === 'disabled' ? false : $open;
}
add_filter('notify_post_author', 'stop_comments_disable_comment_notifications', 10, 2);
add_filter('notify_moderator', 'stop_comments_disable_comment_notifications', 10, 2);

// Update admin settings to reflect comments are disabled
function stop_comments_update_admin_settings() {
    update_option('default_comment_status', 'closed');
    update_option('default_ping_status', 'closed');
}

// Enqueue styles and scripts
function stop_comments_enqueue_assets() {
    wp_enqueue_style('stop-comments-styles', plugin_dir_url(__FILE__) . 'plugin-styles.css');
    wp_enqueue_script('stop-comments-scripts', plugin_dir_url(__FILE__) . 'plugin-scripts.js', array('jquery'), null, true);
}
add_action('wp_enqueue_scripts', 'stop_comments_enqueue_assets');
?>